# Kekas

![](imgs/logo.png)

Kek it easy.

Kekas is a simple tool for training neural networks on Pytorch.

I tried to keep it as simple as possible.

# Installation

`pip install kekas`

# Features

- Awesome name
- Learning Rate Finder
- One Cycle policy
- Best checkpoints saving
- Early stopping
- TTA
- Freeze / unfreeze
- Easy customization
    
# Quick start guide

I don't beieve in quick start guides, I think that they create more questions 
than answers.

Instead, I've created a detailed [Tutorial notebook](Tutorial.ipynb). Read it.

# Contribution guide

Just contribute something good, and don't contribute anything bad.

# TODO

- [ ] AdamW
- [ ] FP16 support 
- [ ] Discriminative learning rates
- [ ] Docs :kekeke: